@@ -91,7 +91,7 @@ class ArcaAPI():
         a = self.curSession.post(URL, data=payload)
         self.check_for_error(a)
 
-    def post_article(self, channel, name, content, category=None):
+    def post_article(self, channel, name, content, category=None, copy_humor=False):
         URL = 'https://arca.live/b/' + channel + '/write'
         csrf = self.getcsrf(URL)
         payload = {'_csrf': csrf[0],
@@ -101,6 +101,8 @@ class ArcaAPI():
                    'title': name,
                    'content': content,
                    }
+        if copy_humor:
+            payload['copyHumorArticle'] = 'on'
         a = self.curSession.post(URL, data=payload)
         self.check_for_error(a)
 
@@ -156,8 +158,8 @@ class ArcaAPI():
         soup = BeautifulSoup(html.text, 'html.parser')
         a = soup.find_all('a', 'vrow')
         response = {}
-        response['notice'] = []
         response['posts'] = []
+        response['notice'] = []
 
         for x in a:
             post = {}
@@ -207,7 +209,8 @@ class ArcaAPI():
         html = self.curSession.get(URL)
         self.check_for_error(html)
         soup = BeautifulSoup(html.text, 'html.parser')
-        response['name'] = (soup.find('div', 'title').text.replace('\n', ''))
+        asoup = soup.find('div', 'article-head')
+        response['name'] = (asoup.find('div', 'title').text.replace('\n', ''))
         info = soup.find('div', 'article-info').find_all('span', 'body')
         response['info'] = {}
         response['info']['like'] = int(info[0].text)
@@ -220,7 +223,7 @@ class ArcaAPI():
         except:
             pass
         try:
-            response['info']['category'] = soup.find('div', 'title').find('span', 'badge badge-success').text
+            response['info']['category'] = asoup.find('div', 'title').find('span', 'badge badge-success').text
             response['name'] = response['name'][len(response['info']['category']):]
         except:
             pass
